@@ -1,22 +1,86 @@
+from functools import lru_cache
 from os.path import join, normpath
 
 from sphinx.errors import SphinxError
 
 from .directives import (auto_class_directive_bound_to_app,
                          auto_function_directive_bound_to_app,
-                         auto_attribute_directive_bound_to_app)
+                         auto_attribute_directive_bound_to_app,
+                         JSStaticFunction)
 from .jsdoc import Analyzer as JsAnalyzer
 from .typedoc import Analyzer as TsAnalyzer
 
 
+# Cache this to guarantee it only runs once.
+@lru_cache(maxsize=None)
+def fix_js_make_xref():
+    """Monkeypatch to fix sphinx.domains.javascript TypedField and GroupedField
+
+    Fixes https://github.com/sphinx-doc/sphinx/issues/11021
+
+    """
+    from docutils import nodes
+
+    from sphinx.domains import javascript
+    from sphinx.locale import _
+
+    class JSXrefMixin:
+        def make_xref(
+            self,
+            rolename,
+            domain,
+            target,
+            innernode=nodes.emphasis,
+            contnode=None,
+            env=None,
+            inliner=None,
+            location=None,
+        ):
+            # Set inliner to None just like the PythonXrefMixin does so the
+            # xref doesn't get rendered as a function.
+            return super().make_xref(
+                rolename, domain, target,
+                innernode, contnode,
+                env, inliner=None, location=None)
+
+    class JSTypedField(JSXrefMixin, javascript.TypedField):
+        pass
+
+    class JSGroupedField(JSXrefMixin, javascript.GroupedField):
+        pass
+
+    # Replace javascript module
+    javascript.TypedField = JSTypedField
+    javascript.GroupedField = JSGroupedField
+
+    # Fix the one place TypedField and GroupedField are used in the javascript
+    # module
+    javascript.JSCallable.doc_field_types = [
+        JSTypedField(
+            'arguments', label=_('Arguments'),
+            names=('argument', 'arg', 'parameter', 'param'),
+            typerolename='func', typenames=('paramtype', 'type')
+        ),
+        JSGroupedField(
+            'errors', label=_('Throws'), rolename='func',
+            names=('throws', ),
+            can_collapse=True
+        ),
+    ] + javascript.JSCallable.doc_field_types[2:]
+
+
+fix_js_make_xref()
+
+
 def setup(app):
     # I believe this is the best place to run jsdoc. I was tempted to use
     # app.add_source_parser(), but I think the kind of source it's referring to
     # is RSTs.
     app.connect('builder-inited', analyze)
 
-    app.connect('env-before-read-docs', read_all_docs)
-
+    app.add_directive_to_domain('js',
+                                'staticfunction',
+                                JSStaticFunction)
     app.add_directive_to_domain('js',
                                 'autofunction',
                                 auto_function_directive_bound_to_app(app))
@@ -28,9 +92,9 @@ def setup(app):
                                 auto_attribute_directive_bound_to_app(app))
     # TODO: We could add a js:module with app.add_directive_to_domain().
 
-    app.add_config_value('js_language', 'javascript', 'env')
-    app.add_config_value('js_source_path', '../', 'env')
-    app.add_config_value('jsdoc_config_path', None, 'env')
+    app.add_config_value('js_language', default='javascript', rebuild='env')
+    app.add_config_value('js_source_path', default=['../'], rebuild='env', types=[str, list])
+    app.add_config_value('jsdoc_config_path', default=None, rebuild='env')
 
     # We could use a callable as the "default" param here, but then we would
     # have had to duplicate or build framework around the logic that promotes
@@ -79,14 +143,3 @@ def root_or_fallback(root_for_relative_paths, abs_source_paths):
             raise SphinxError('Since more than one js_source_path is specified in conf.py, root_for_relative_js_paths must also be specified. This allows paths beginning with ./ or ../ to be unambiguous.')
         else:
             return abs_source_paths[0]
-
-
-def read_all_docs(app, env, doc_names):
-    """Add all found docs to the to-be-read list, because we have no way of
-    telling which ones reference JS code that might have changed.
-
-    Otherwise, builds go stale until you touch the stale RSTs or do a ``make
-    clean``.
-
-    """
-    doc_names[:] = env.found_docs
