@@ -5,7 +5,7 @@ from docutils.statemachine import StringList
 from docutils.utils import new_document
 from jinja2 import Environment, PackageLoader
 from sphinx.errors import SphinxError
-from sphinx.util import rst
+from sphinx.util import logging, rst
 
 from .analyzer_utils import dotted_path
 from .ir import Class, Function, Interface, Pathname
@@ -13,6 +13,9 @@ from .parsers import PathVisitor
 from .suffix_tree import SuffixAmbiguous, SuffixNotFound
 
 
+logger = logging.getLogger(__name__)
+
+
 class JsRenderer(object):
     """Abstract superclass for renderers of various sphinx-js directives
 
@@ -57,6 +60,35 @@ class JsRenderer(object):
                    content=directive.content,
                    options=directive.options)
 
+    def get_object(self):
+        """Return the IR object rendered by this renderer.
+
+        """
+        try:
+            obj = self._app._sphinxjs_analyzer.get_object(
+                self._partial_path, self._renderer_type)
+            return obj
+        except SuffixNotFound as exc:
+            raise SphinxError('No documentation was found for object "%s" or any path ending with that.'
+                              % ''.join(exc.segments))
+        except SuffixAmbiguous as exc:
+            raise SphinxError('More than one object matches the path suffix "%s". Candidate paths have these segments in front: %s'
+                              % (''.join(exc.segments), exc.next_possible_keys))
+
+    def dependencies(self):
+        """Return a set of path(s) to the file(s) that the IR object
+        rendered by this renderer is from.  Each path is absolute or
+        relative to `root_for_relative_js_paths`.
+
+        """
+        try:
+            obj = self.get_object()
+            if obj.deppath:
+                return set([obj.deppath])
+        except SphinxError as exc:
+            logger.exception('Exception while retrieving paths for IR object: %s' % exc)
+        return set([])
+
     def rst_nodes(self):
         """Render into RST nodes a thing shaped like a function, having a name
         and arguments.
@@ -64,32 +96,22 @@ class JsRenderer(object):
         Fill in args, docstrings, and info fields from stored JSDoc output.
 
         """
-        try:
-            obj = self._app._sphinxjs_analyzer.get_object(
-                self._partial_path, self._renderer_type)
-        except SuffixNotFound as exc:
-            raise SphinxError('No documentation was found for object "%s" or any path ending with that.'
-                              % ''.join(exc.segments))
-        except SuffixAmbiguous as exc:
-            raise SphinxError('More than one object matches the path suffix "%s". Candidate paths have these segments in front: %s'
-                              % (''.join(exc.segments), exc.next_possible_keys))
-        else:
-            rst = self.rst(self._partial_path,
-                           obj,
-                           use_short_name='short-name' in self._options)
+        obj = self.get_object()
+        rst = self.rst(self._partial_path,
+                       obj,
+                       use_short_name='short-name' in self._options)
 
-            # Parse the RST into docutils nodes with a fresh doc, and return
-            # them.
-            #
-            # Not sure if passing the settings from the "real" doc is the right
-            # thing to do here:
-            doc = new_document('%s:%s(%s)' % (obj.filename,
-                                              obj.path,
-                                              obj.line),
-                               settings=self._directive.state.document.settings)
-            RstParser().parse(rst, doc)
-            return doc.children
-        return []
+        # Parse the RST into docutils nodes with a fresh doc, and return
+        # them.
+        #
+        # Not sure if passing the settings from the "real" doc is the right
+        # thing to do here:
+        doc = new_document('%s:%s(%s)' % (obj.filename,
+                                          obj.path,
+                                          obj.line),
+                           settings=self._directive.state.document.settings)
+        RstParser().parse(rst, doc)
+        return doc.children
 
     def rst(self, partial_path, obj, use_short_name=False):
         """Return rendered RST about an entity with the given name and IR
@@ -178,6 +200,7 @@ class AutoFunctionRenderer(JsRenderer):
             examples=obj.examples,
             deprecated=obj.deprecated,
             is_optional=obj.is_optional,
+            is_static=obj.is_static,
             see_also=obj.see_alsos,
             content='\n'.join(self._content))
 
@@ -198,6 +221,7 @@ class AutoClassRenderer(JsRenderer):
                 name='',
                 path=Pathname([]),
                 filename='',
+                deppath=None,
                 description='',
                 line=0,
                 deprecated=False,
