@@ -4,10 +4,11 @@ from codecs import getreader
 from errno import ENOENT
 from json import load
 from os.path import basename, join, normpath, relpath, sep, splitext
+from platform import node
 import re
 import subprocess
 from tempfile import NamedTemporaryFile
-from typing import List, Optional, Tuple, Union
+from typing import Iterator, List, Optional, Tuple, Union
 
 from sphinx.errors import SphinxError
 
@@ -56,9 +57,8 @@ class Analyzer:
         """
         return self._objects_by_path.get(path_suffix)
 
-    def _containing_module(self, node) -> Optional[Pathname]:
-        """Return the Pathname pointing to the module containing the given
-        node, None if one isn't found."""
+    def _parent_nodes(self, node) -> Iterator[node]:
+        """Return an iterator of parent nodes"""
         while True:
             node = node.get('__parent')
             if not node or node['id'] == 0:
@@ -66,7 +66,28 @@ class Analyzer:
                 return
             elif node.get('kindString') == 'External module':
                 # Found one!
-                return Pathname(make_path_segments(node, self._base_dir))
+                yield node
+
+    def _containing_module(self, node) -> Optional[Pathname]:
+        """Return the Pathname pointing to the module containing the given
+        node, None if one isn't found."""
+        for node in self._parent_nodes(node):
+            return Pathname(make_path_segments(node, self._base_dir))
+        return None
+
+    def _containing_deppath(self, node) -> Optional[Pathname]:
+        """Return the path pointing to the module containing the given node.
+        The path is absolute or relative to `root_for_relative_js_paths`.
+        Raises ValueError if one isn't found.
+
+        """
+        for node in self._parent_nodes(node):
+            deppath = node.get('originalName')
+            if deppath:
+                return relpath(deppath, self._base_dir)
+            else:
+                raise ValueError('Could not find deppath')
+        raise ValueError('Could not find deppath')
 
     def _top_level_properties(self, node):
         source = node.get('sources')[0]
@@ -78,6 +99,7 @@ class Analyzer:
             name=short_name(node),
             path=Pathname(make_path_segments(node, self._base_dir)),
             filename=basename(source['fileName']),
+            deppath=self._containing_deppath(node),
             description=make_description(node.get('comment', {})),
             line=source['line'],
 
